summaryrefslogtreecommitdiffstats
path: root/controller-server
diff options
context:
space:
mode:
authorJon Marius Venstad <venstad@gmail.com>2021-05-12 08:44:16 +0200
committerJon Marius Venstad <venstad@gmail.com>2021-05-12 08:44:16 +0200
commite73d607541131e4231c7e580b09bae761c89cec3 (patch)
tree66eab037bda2e525629bde22f6b969ab60025a6c /controller-server
parent54a4fcf8a3a558187353e85980075831f94a3a48 (diff)
11px font, up from 10px
Diffstat (limited to 'controller-server')
-rw-r--r--controller-server/src/main/java/com/yahoo/vespa/hosted/controller/restapi/deployment/Badges.java10
-rw-r--r--controller-server/src/test/java/com/yahoo/vespa/hosted/controller/restapi/deployment/responses/history.svg220
-rw-r--r--controller-server/src/test/java/com/yahoo/vespa/hosted/controller/restapi/deployment/responses/overview.svg98
3 files changed, 164 insertions, 164 deletions
diff --git a/controller-server/src/test/java/com/yahoo/vespa/hosted/controller/restapi/deployment/responses/history.svg b/controller-server/src/test/java/com/yahoo/vespa/hosted/controller/restapi/deployment/responses/history.svg
index a081b21ec3f..d2c82f1e8e4 100644
--- a/controller-server/src/test/java/com/yahoo/vespa/hosted/controller/restapi/deployment/responses/history.svg
+++ b/controller-server/src/test/java/com/yahoo/vespa/hosted/controller/restapi/deployment/responses/history.svg
@@ -1,4 +1,4 @@
-<svg xmlns='http://www.w3.org/2000/svg' width='616.7390658896196' height='20' role='img' aria-label='Deployment Status'>
+<svg xmlns='http://www.w3.org/2000/svg' width='640.4367858896197' height='20' role='img' aria-label='Deployment Status'>
<title>Deployment Status</title>
<linearGradient id='light' x2='0' y2='100%'>
<stop offset='0' stop-color='#fff' stop-opacity='.5'/>
@@ -39,115 +39,115 @@
<animate attributeName='x2' values='-10%;250%;120%;-10%' dur='6s' repeatCount='indefinite' />
</linearGradient>
<clipPath id='rounded'>
- <rect width='616.7390658896196' height='20' rx='3' fill='#fff'/>
+ <rect width='640.4367858896197' height='20' rx='3' fill='#fff'/>
</clipPath>
<g clip-path='url(#rounded)'>
- <rect x='610.9256720815912' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='604.6322196342305' rx='3' width='12.293452447360632' height='20' fill='#00ff48'/>
- <rect x='604.6322196342305' rx='3' width='12.293452447360632' height='20' fill='url(#shade)'/>
- <rect x='604.8245279299437' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='598.3387671868699' rx='3' width='12.485760743073765' height='20' fill='#bf103c'/>
- <rect x='598.3387671868699' rx='3' width='12.485760743073765' height='20' fill='url(#shade)'/>
- <rect x='598.5369518248465' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='591.8530064437961' rx='3' width='12.68394538105045' height='20' fill='#bf103c'/>
- <rect x='591.8530064437961' rx='3' width='12.68394538105045' height='20' fill='url(#shade)'/>
- <rect x='592.0572469867445' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='585.1690610627456' rx='3' width='12.888185923998947' height='20' fill='#bf103c'/>
- <rect x='585.1690610627456' rx='3' width='12.888185923998947' height='20' fill='url(#shade)'/>
- <rect x='585.3795425602511' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='578.2808751387468' rx='3' width='13.098667421504338' height='20' fill='#bf103c'/>
- <rect x='578.2808751387468' rx='3' width='13.098667421504338' height='20' fill='url(#shade)'/>
- <rect x='578.4977882949328' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='571.1822077172424' rx='3' width='13.31558057769039' height='20' fill='#bf103c'/>
- <rect x='571.1822077172424' rx='3' width='13.31558057769039' height='20' fill='url(#shade)'/>
- <rect x='571.4057490635566' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='563.866627139552' rx='3' width='13.539121924004645' height='20' fill='#bf103c'/>
- <rect x='563.866627139552' rx='3' width='13.539121924004645' height='20' fill='url(#shade)'/>
- <rect x='564.0969992128305' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='556.3275052155473' rx='3' width='13.769493997283261' height='20' fill='#bf103c'/>
- <rect x='556.3275052155473' rx='3' width='13.769493997283261' height='20' fill='url(#shade)'/>
- <rect x='556.564916741521' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='548.558011218264' rx='3' width='14.006905523256986' height='20' fill='#bf103c'/>
- <rect x='548.558011218264' rx='3' width='14.006905523256986' height='20' fill='url(#shade)'/>
- <rect x='548.8026773006716' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='540.5511056950071' rx='3' width='14.251571605664486' height='20' fill='#bf103c'/>
- <rect x='540.5511056950071' rx='3' width='14.251571605664486' height='20' fill='url(#shade)'/>
- <rect x='540.803248010487' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='532.2995340893426' rx='3' width='14.503713921144396' height='20' fill='#bf103c'/>
- <rect x='532.2995340893426' rx='3' width='14.503713921144396' height='20' fill='url(#shade)'/>
- <rect x='532.5593810882809' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='523.7958201681982' rx='3' width='14.763560920082657' height='20' fill='#bf103c'/>
- <rect x='523.7958201681982' rx='3' width='14.763560920082657' height='20' fill='url(#shade)'/>
- <rect x='524.0636072817127' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='515.0322592481156' rx='3' width='15.031348033597132' height='20' fill='#bf103c'/>
- <rect x='515.0322592481156' rx='3' width='15.031348033597132' height='20' fill='url(#shade)'/>
- <rect x='515.3082291013654' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='506.0009112145184' rx='3' width='15.307317886847013' height='20' fill='#bf103c'/>
- <rect x='506.0009112145184' rx='3' width='15.307317886847013' height='20' fill='url(#shade)'/>
- <rect x='506.2853138465317' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='496.6935933276714' rx='3' width='15.591720518860313' height='20' fill='#bf103c'/>
- <rect x='496.6935933276714' rx='3' width='15.591720518860313' height='20' fill='url(#shade)'/>
- <rect x='496.9866864178897' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='487.1018728088111' rx='3' width='15.884813609078591' height='20' fill='#bf103c'/>
- <rect x='487.1018728088111' rx='3' width='15.884813609078591' height='20' fill='url(#shade)'/>
- <rect x='487.4039219105567' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='477.2170591997325' rx='3' width='16.186862710824187' height='20' fill='#bf103c'/>
- <rect x='477.2170591997325' rx='3' width='16.186862710824187' height='20' fill='url(#shade)'/>
- <rect x='477.5283379808098' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='467.0301964889083' rx='3' width='16.498141491901468' height='20' fill='#bf103c'/>
- <rect x='467.0301964889083' rx='3' width='16.498141491901468' height='20' fill='url(#shade)'/>
- <rect x='467.3509869795569' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='456.5320549970068' rx='3' width='16.81893198255014' height='20' fill='#bf103c'/>
- <rect x='456.5320549970068' rx='3' width='16.81893198255014' height='20' fill='url(#shade)'/>
- <rect x='456.86264784543187' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='445.7131230144567' rx='3' width='17.14952483097518' height='20' fill='#bf103c'/>
- <rect x='445.7131230144567' rx='3' width='17.14952483097518' height='20' fill='url(#shade)'/>
- <rect x='446.05381775016656' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='434.56359818348153' rx='3' width='17.49021956668504' height='20' fill='#bf103c'/>
- <rect x='434.56359818348153' rx='3' width='17.49021956668504' height='20' fill='url(#shade)'/>
- <rect x='434.91470348867307' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='423.0733786167965' rx='3' width='17.841324871876566' height='20' fill='#bf103c'/>
- <rect x='423.0733786167965' rx='3' width='17.841324871876566' height='20' fill='url(#shade)'/>
- <rect x='423.43521260603256' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='411.23205374491994' rx='3' width='18.20315886111265' height='20' fill='#bf103c'/>
- <rect x='411.23205374491994' rx='3' width='18.20315886111265' height='20' fill='url(#shade)'/>
- <rect x='411.60494425335327' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='399.0288948838073' rx='3' width='18.576049369545963' height='20' fill='#bf103c'/>
- <rect x='399.0288948838073' rx='3' width='18.576049369545963' height='20' fill='url(#shade)'/>
- <rect x='399.41317976421124' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='386.45284551426136' rx='3' width='18.960334249949863' height='20' fill='#bf103c'/>
- <rect x='386.45284551426136' rx='3' width='18.960334249949863' height='20' fill='url(#shade)'/>
- <rect x='386.84887294313717' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='373.4925112643115' rx='3' width='19.35636167882567' height='20' fill='#bf103c'/>
- <rect x='373.4925112643115' rx='3' width='19.35636167882567' height='20' fill='url(#shade)'/>
- <rect x='373.90064005734945' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='360.1361495854858' rx='3' width='19.764490471863645' height='20' fill='#bf103c'/>
- <rect x='360.1361495854858' rx='3' width='19.764490471863645' height='20' fill='url(#shade)'/>
- <rect x='360.55674952266554' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='346.3716591136221' rx='3' width='20.18509040904341' height='20' fill='#bf103c'/>
- <rect x='346.3716591136221' rx='3' width='20.18509040904341' height='20' fill='url(#shade)'/>
- <rect x='346.8051112742472' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='332.1865687045787' rx='3' width='20.61854256966852' height='20' fill='#bf103c'/>
- <rect x='332.1865687045787' rx='3' width='20.61854256966852' height='20' fill='url(#shade)'/>
- <rect x='332.6332658125487' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='317.56802613491016' rx='3' width='21.06523967763854' height='20' fill='#bf103c'/>
- <rect x='317.56802613491016' rx='3' width='21.06523967763854' height='20' fill='url(#shade)'/>
- <rect x='318.02837291454324' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='302.5027864572716' rx='3' width='21.525586457271643' height='20' fill='#bf103c'/>
- <rect x='302.5027864572716' rx='3' width='21.525586457271643' height='20' fill='url(#shade)'/>
- <rect x='302.9772' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='286.9772' rx='3' width='22.0' height='20' fill='#bf103c'/>
- <rect x='286.9772' rx='3' width='22.0' height='20' fill='url(#shade)'/>
- <rect x='286.9772' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='162.7498' rx='3' width='130.2274' height='20' fill='url(#run-on-failure)'/>
- <rect x='162.7498' rx='3' width='130.2274' height='20' fill='url(#shade)'/>
- <rect width='168.7498' height='20' fill='#5a5a5a'/>
- <rect x='-6.0' rx='3' width='174.7498' height='20' fill='url(#shade)'/>
+ <rect x='634.6233920815913' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='628.3299396342306' rx='3' width='12.293452447360632' height='20' fill='#00ff48'/>
+ <rect x='628.3299396342306' rx='3' width='12.293452447360632' height='20' fill='url(#shade)'/>
+ <rect x='628.5222479299438' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='622.03648718687' rx='3' width='12.485760743073765' height='20' fill='#bf103c'/>
+ <rect x='622.03648718687' rx='3' width='12.485760743073765' height='20' fill='url(#shade)'/>
+ <rect x='622.2346718248466' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='615.5507264437962' rx='3' width='12.68394538105045' height='20' fill='#bf103c'/>
+ <rect x='615.5507264437962' rx='3' width='12.68394538105045' height='20' fill='url(#shade)'/>
+ <rect x='615.7549669867446' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='608.8667810627458' rx='3' width='12.888185923998947' height='20' fill='#bf103c'/>
+ <rect x='608.8667810627458' rx='3' width='12.888185923998947' height='20' fill='url(#shade)'/>
+ <rect x='609.0772625602513' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='601.9785951387469' rx='3' width='13.098667421504338' height='20' fill='#bf103c'/>
+ <rect x='601.9785951387469' rx='3' width='13.098667421504338' height='20' fill='url(#shade)'/>
+ <rect x='602.1955082949329' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='594.8799277172425' rx='3' width='13.31558057769039' height='20' fill='#bf103c'/>
+ <rect x='594.8799277172425' rx='3' width='13.31558057769039' height='20' fill='url(#shade)'/>
+ <rect x='595.1034690635568' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='587.5643471395521' rx='3' width='13.539121924004645' height='20' fill='#bf103c'/>
+ <rect x='587.5643471395521' rx='3' width='13.539121924004645' height='20' fill='url(#shade)'/>
+ <rect x='587.7947192128306' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='580.0252252155474' rx='3' width='13.769493997283261' height='20' fill='#bf103c'/>
+ <rect x='580.0252252155474' rx='3' width='13.769493997283261' height='20' fill='url(#shade)'/>
+ <rect x='580.2626367415211' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='572.2557312182641' rx='3' width='14.006905523256986' height='20' fill='#bf103c'/>
+ <rect x='572.2557312182641' rx='3' width='14.006905523256986' height='20' fill='url(#shade)'/>
+ <rect x='572.5003973006717' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='564.2488256950072' rx='3' width='14.251571605664486' height='20' fill='#bf103c'/>
+ <rect x='564.2488256950072' rx='3' width='14.251571605664486' height='20' fill='url(#shade)'/>
+ <rect x='564.5009680104871' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='555.9972540893427' rx='3' width='14.503713921144396' height='20' fill='#bf103c'/>
+ <rect x='555.9972540893427' rx='3' width='14.503713921144396' height='20' fill='url(#shade)'/>
+ <rect x='556.257101088281' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='547.4935401681984' rx='3' width='14.763560920082657' height='20' fill='#bf103c'/>
+ <rect x='547.4935401681984' rx='3' width='14.763560920082657' height='20' fill='url(#shade)'/>
+ <rect x='547.7613272817129' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='538.7299792481157' rx='3' width='15.031348033597132' height='20' fill='#bf103c'/>
+ <rect x='538.7299792481157' rx='3' width='15.031348033597132' height='20' fill='url(#shade)'/>
+ <rect x='539.0059491013656' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='529.6986312145185' rx='3' width='15.307317886847013' height='20' fill='#bf103c'/>
+ <rect x='529.6986312145185' rx='3' width='15.307317886847013' height='20' fill='url(#shade)'/>
+ <rect x='529.9830338465317' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='520.3913133276715' rx='3' width='15.591720518860313' height='20' fill='#bf103c'/>
+ <rect x='520.3913133276715' rx='3' width='15.591720518860313' height='20' fill='url(#shade)'/>
+ <rect x='520.6844064178897' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='510.7995928088111' rx='3' width='15.884813609078591' height='20' fill='#bf103c'/>
+ <rect x='510.7995928088111' rx='3' width='15.884813609078591' height='20' fill='url(#shade)'/>
+ <rect x='511.10164191055674' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='500.91477919973255' rx='3' width='16.186862710824187' height='20' fill='#bf103c'/>
+ <rect x='500.91477919973255' rx='3' width='16.186862710824187' height='20' fill='url(#shade)'/>
+ <rect x='501.22605798080986' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='490.72791648890836' rx='3' width='16.498141491901468' height='20' fill='#bf103c'/>
+ <rect x='490.72791648890836' rx='3' width='16.498141491901468' height='20' fill='url(#shade)'/>
+ <rect x='491.048706979557' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='480.22977499700687' rx='3' width='16.81893198255014' height='20' fill='#bf103c'/>
+ <rect x='480.22977499700687' rx='3' width='16.81893198255014' height='20' fill='url(#shade)'/>
+ <rect x='480.5603678454319' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='469.41084301445676' rx='3' width='17.14952483097518' height='20' fill='#bf103c'/>
+ <rect x='469.41084301445676' rx='3' width='17.14952483097518' height='20' fill='url(#shade)'/>
+ <rect x='469.7515377501666' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='458.2613181834816' rx='3' width='17.49021956668504' height='20' fill='#bf103c'/>
+ <rect x='458.2613181834816' rx='3' width='17.49021956668504' height='20' fill='url(#shade)'/>
+ <rect x='458.61242348867313' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='446.77109861679656' rx='3' width='17.841324871876566' height='20' fill='#bf103c'/>
+ <rect x='446.77109861679656' rx='3' width='17.841324871876566' height='20' fill='url(#shade)'/>
+ <rect x='447.1329326060326' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='434.92977374492' rx='3' width='18.20315886111265' height='20' fill='#bf103c'/>
+ <rect x='434.92977374492' rx='3' width='18.20315886111265' height='20' fill='url(#shade)'/>
+ <rect x='435.3026642533533' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='422.7266148838074' rx='3' width='18.576049369545963' height='20' fill='#bf103c'/>
+ <rect x='422.7266148838074' rx='3' width='18.576049369545963' height='20' fill='url(#shade)'/>
+ <rect x='423.1108997642113' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='410.1505655142614' rx='3' width='18.960334249949863' height='20' fill='#bf103c'/>
+ <rect x='410.1505655142614' rx='3' width='18.960334249949863' height='20' fill='url(#shade)'/>
+ <rect x='410.5465929431372' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='397.19023126431154' rx='3' width='19.35636167882567' height='20' fill='#bf103c'/>
+ <rect x='397.19023126431154' rx='3' width='19.35636167882567' height='20' fill='url(#shade)'/>
+ <rect x='397.5983600573495' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='383.83386958548584' rx='3' width='19.764490471863645' height='20' fill='#bf103c'/>
+ <rect x='383.83386958548584' rx='3' width='19.764490471863645' height='20' fill='url(#shade)'/>
+ <rect x='384.2544695226656' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='370.0693791136222' rx='3' width='20.18509040904341' height='20' fill='#bf103c'/>
+ <rect x='370.0693791136222' rx='3' width='20.18509040904341' height='20' fill='url(#shade)'/>
+ <rect x='370.5028312742473' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='355.88428870457875' rx='3' width='20.61854256966852' height='20' fill='#bf103c'/>
+ <rect x='355.88428870457875' rx='3' width='20.61854256966852' height='20' fill='url(#shade)'/>
+ <rect x='356.33098581254876' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='341.2657461349102' rx='3' width='21.06523967763854' height='20' fill='#bf103c'/>
+ <rect x='341.2657461349102' rx='3' width='21.06523967763854' height='20' fill='url(#shade)'/>
+ <rect x='341.7260929145433' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='326.2005064572717' rx='3' width='21.525586457271643' height='20' fill='#bf103c'/>
+ <rect x='326.2005064572717' rx='3' width='21.525586457271643' height='20' fill='url(#shade)'/>
+ <rect x='326.67492000000004' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='310.67492000000004' rx='3' width='22.0' height='20' fill='#bf103c'/>
+ <rect x='310.67492000000004' rx='3' width='22.0' height='20' fill='url(#shade)'/>
+ <rect x='310.67492000000004' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='175.62478000000002' rx='3' width='141.05014' height='20' fill='url(#run-on-failure)'/>
+ <rect x='175.62478000000002' rx='3' width='141.05014' height='20' fill='url(#shade)'/>
+ <rect width='181.62478000000002' height='20' fill='#5a5a5a'/>
+ <rect x='-6.0' rx='3' width='187.62478000000002' height='20' fill='url(#shade)'/>
<rect width='2' height='20' fill='url(#left-light)'/>
- <rect x='614.7390658896196' width='2' height='20' fill='url(#right-shadow)'/>
- <rect width='616.7390658896196' height='20' fill='url(#light)'/>
+ <rect x='638.4367858896197' width='2' height='20' fill='url(#right-shadow)'/>
+ <rect width='640.4367858896197' height='20' fill='url(#light)'/>
</g>
- <g fill='#fff' text-anchor='middle' font-family='Verdana,Geneva,DejaVu Sans,sans-serif' text-rendering='geometricPrecision' font-size='10'>
+ <g fill='#fff' text-anchor='middle' font-family='Verdana,Geneva,DejaVu Sans,sans-serif' text-rendering='geometricPrecision' font-size='11'>
<svg x='8.5' y='3.0' width='16.0' height='16.0' viewBox='0 0 150 150'>
<polygon fill='#402a14' fill-opacity='0.5' points='84.84 10 34.1 44.46 34.1 103.78 84.84 68.02 135.57 103.78 135.57 44.46 84.84 10'/>
<polygon fill='#402a14' fill-opacity='0.5' points='84.84 68.02 84.84 10 135.57 44.46 135.57 103.78 84.84 68.02'/>
@@ -168,9 +168,9 @@
<polygon fill='#1a7db6' points='65.07 81.99 14.34 46.22 14.34 105.54 65.07 140 115.81 105.54 115.81 46.22 65.07 81.99'/>
<polygon fill='url(#blue-shaded)' points='65.07 81.99 65.07 140 14.34 105.54 14.34 46.22 65.07 81.99'/>
</svg>
- <text x='96.8749' y='14' fill='#000' fill-opacity='.3' textLength='128.7498'>tenant.application.default</text>
- <text x='96.3749' y='13' fill='#fff' textLength='128.7498'>tenant.application.default</text>
- <text x='231.3635' y='14' fill='#000' fill-opacity='.3' textLength='108.22739999999999'>production-us-west-1</text>
- <text x='230.8635' y='13' fill='#fff' textLength='108.22739999999999'>production-us-west-1</text>
+ <text x='103.31239000000001' y='15' fill='#000' fill-opacity='.3' textLength='141.62478000000002'>tenant.application.default</text>
+ <text x='102.81239000000001' y='14' fill='#fff' textLength='141.62478000000002'>tenant.application.default</text>
+ <text x='249.64985000000001' y='15' fill='#000' fill-opacity='.3' textLength='119.05014'>production-us-west-1</text>
+ <text x='249.14985000000001' y='14' fill='#fff' textLength='119.05014'>production-us-west-1</text>
</g>
</svg>
diff --git a/controller-server/src/test/java/com/yahoo/vespa/hosted/controller/restapi/deployment/responses/overview.svg b/controller-server/src/test/java/com/yahoo/vespa/hosted/controller/restapi/deployment/responses/overview.svg
index 68e3335fff0..5791068ca2a 100644
--- a/controller-server/src/test/java/com/yahoo/vespa/hosted/controller/restapi/deployment/responses/overview.svg
+++ b/controller-server/src/test/java/com/yahoo/vespa/hosted/controller/restapi/deployment/responses/overview.svg
@@ -1,4 +1,4 @@
-<svg xmlns='http://www.w3.org/2000/svg' width='768.8784' height='20' role='img' aria-label='Deployment Status'>
+<svg xmlns='http://www.w3.org/2000/svg' width='828.9662400000001' height='20' role='img' aria-label='Deployment Status'>
<title>Deployment Status</title>
<linearGradient id='light' x2='0' y2='100%'>
<stop offset='0' stop-color='#fff' stop-opacity='.5'/>
@@ -39,34 +39,34 @@
<animate attributeName='x2' values='-10%;250%;120%;-10%' dur='6s' repeatCount='indefinite' />
</linearGradient>
<clipPath id='rounded'>
- <rect width='768.8784' height='20' rx='3' fill='#fff'/>
+ <rect width='828.9662400000001' height='20' rx='3' fill='#fff'/>
</clipPath>
<g clip-path='url(#rounded)'>
- <rect x='762.8784' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='725.8306' rx='3' width='43.0478' height='20' fill='url(#run-on-success)'/>
- <polygon points='627.6657 0 627.6657 20 733.3306 20 741.3306 0' fill='#00ff48'/>
- <rect x='627.6657' rx='3' width='141.2127' height='20' fill='url(#shade)'/>
- <rect x='627.6657' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='590.6179' rx='3' width='43.0478' height='20' fill='#bf103c'/>
- <polygon points='466.8035 0 466.8035 20 598.1179 20 606.1179 0' fill='#00ff48'/>
- <rect x='466.8035' rx='3' width='166.86219999999997' height='20' fill='url(#shade)'/>
- <rect x='466.8035' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='362.7663' rx='3' width='110.0372' height='20' fill='url(#run-on-success)'/>
- <rect x='372.7663' rx='3' width='100.0372' height='20' fill='url(#shade)'/>
- <rect x='372.7663' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='335.7185' rx='3' width='43.0478' height='20' fill='#00ff48'/>
- <polygon points='238.3006 0 238.3006 20 343.2185 20 351.2185 0' fill='url(#run-on-failure)'/>
- <rect x='238.3006' rx='3' width='140.4657' height='20' fill='url(#shade)'/>
- <rect x='238.3006' rx='3' width='9' height='20' fill='url(#shadow)'/>
- <rect x='152.7498' rx='3' width='91.55080000000001' height='20' fill='#00ff48'/>
- <rect x='162.7498' rx='3' width='81.55080000000001' height='20' fill='url(#shade)'/>
- <rect width='168.7498' height='20' fill='#5a5a5a'/>
- <rect x='-6.0' rx='3' width='174.7498' height='20' fill='url(#shade)'/>
+ <rect x='822.9662400000001' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='784.0136600000001' rx='3' width='44.95258' height='20' fill='url(#run-on-success)'/>
+ <polygon points='677.43227 0 677.43227 20 791.5136600000001 20 799.5136600000001 0' fill='#00ff48'/>
+ <rect x='677.43227' rx='3' width='151.53397' height='20' fill='url(#shade)'/>
+ <rect x='677.43227' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='638.47969' rx='3' width='44.95258' height='20' fill='#bf103c'/>
+ <polygon points='503.68385 0 503.68385 20 645.97969 20 653.97969 0' fill='#00ff48'/>
+ <rect x='503.68385' rx='3' width='179.74842' height='20' fill='url(#shade)'/>
+ <rect x='503.68385' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='391.84293' rx='3' width='117.84091999999998' height='20' fill='url(#run-on-success)'/>
+ <rect x='401.84293' rx='3' width='107.84091999999998' height='20' fill='url(#shade)'/>
+ <rect x='401.84293' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='362.89035' rx='3' width='44.95258' height='20' fill='#00ff48'/>
+ <polygon points='257.13066000000003 0 257.13066000000003 20 370.39035 20 378.39035 0' fill='url(#run-on-failure)'/>
+ <rect x='257.13066000000003' rx='3' width='150.71227000000002' height='20' fill='url(#shade)'/>
+ <rect x='257.13066000000003' rx='3' width='9' height='20' fill='url(#shadow)'/>
+ <rect x='165.62478000000002' rx='3' width='97.50588' height='20' fill='#00ff48'/>
+ <rect x='175.62478000000002' rx='3' width='87.50588' height='20' fill='url(#shade)'/>
+ <rect width='181.62478000000002' height='20' fill='#5a5a5a'/>
+ <rect x='-6.0' rx='3' width='187.62478000000002' height='20' fill='url(#shade)'/>
<rect width='2' height='20' fill='url(#left-light)'/>
- <rect x='766.8784' width='2' height='20' fill='url(#right-shadow)'/>
- <rect width='768.8784' height='20' fill='url(#light)'/>
+ <rect x='826.9662400000001' width='2' height='20' fill='url(#right-shadow)'/>
+ <rect width='828.9662400000001' height='20' fill='url(#light)'/>
</g>
- <g fill='#fff' text-anchor='middle' font-family='Verdana,Geneva,DejaVu Sans,sans-serif' text-rendering='geometricPrecision' font-size='10'>
+ <g fill='#fff' text-anchor='middle' font-family='Verdana,Geneva,DejaVu Sans,sans-serif' text-rendering='geometricPrecision' font-size='11'>
<svg x='8.5' y='3.0' width='16.0' height='16.0' viewBox='0 0 150 150'>
<polygon fill='#402a14' fill-opacity='0.5' points='84.84 10 34.1 44.46 34.1 103.78 84.84 68.02 135.57 103.78 135.57 44.46 84.84 10'/>
<polygon fill='#402a14' fill-opacity='0.5' points='84.84 68.02 84.84 10 135.57 44.46 135.57 103.78 84.84 68.02'/>
@@ -87,29 +87,29 @@
<polygon fill='#1a7db6' points='65.07 81.99 14.34 46.22 14.34 105.54 65.07 140 115.81 105.54 115.81 46.22 65.07 81.99'/>
<polygon fill='url(#blue-shaded)' points='65.07 81.99 65.07 140 14.34 105.54 14.34 46.22 65.07 81.99'/>
</svg>
- <text x='96.8749' y='14' fill='#000' fill-opacity='.3' textLength='128.7498'>tenant.application.default</text>
- <text x='96.3749' y='13' fill='#fff' textLength='128.7498'>tenant.application.default</text>
- <text x='207.02519999999998' y='14' fill='#000' fill-opacity='.3' textLength='59.5508'>system-test</text>
- <text x='206.52519999999998' y='13' fill='#fff' textLength='59.5508'>system-test</text>
- <text x='277.93485' y='14' fill='#000' fill-opacity='.3' textLength='50.2685'>us-west-1</text>
- <text x='277.43485' y='13' fill='#fff' textLength='50.2685'>us-west-1</text>
- <text x='327.6438' y='14' fill='#000' fill-opacity='.3' textLength='33.1494'>deploy</text>
- <text x='327.1438' y='13' fill='#fff' textLength='33.1494'>deploy</text>
- <text x='361.74240000000003' y='14' fill='#000' fill-opacity='.3' textLength='19.047800000000002'>test</text>
- <text x='361.24240000000003' y='13' fill='#fff' textLength='19.047800000000002'>test</text>
- <text x='426.2849' y='14' fill='#000' fill-opacity='.3' textLength='78.0372'>aws-us-east-1a</text>
- <text x='425.7849' y='13' fill='#fff' textLength='78.0372'>aws-us-east-1a</text>
- <text x='519.636' y='14' fill='#000' fill-opacity='.3' textLength='76.66499999999999'>ap-southeast-1</text>
- <text x='519.136' y='13' fill='#fff' textLength='76.66499999999999'>ap-southeast-1</text>
- <text x='582.5432' y='14' fill='#000' fill-opacity='.3' textLength='33.1494'>deploy</text>
- <text x='582.0432' y='13' fill='#fff' textLength='33.1494'>deploy</text>
- <text x='616.6418' y='14' fill='#000' fill-opacity='.3' textLength='19.047800000000002'>test</text>
- <text x='616.1418' y='13' fill='#fff' textLength='19.047800000000002'>test</text>
- <text x='667.67345' y='14' fill='#000' fill-opacity='.3' textLength='51.015499999999996'>eu-west-1</text>
- <text x='667.17345' y='13' fill='#fff' textLength='51.015499999999996'>eu-west-1</text>
- <text x='717.7559' y='14' fill='#000' fill-opacity='.3' textLength='33.1494'>deploy</text>
- <text x='717.2559' y='13' fill='#fff' textLength='33.1494'>deploy</text>
- <text x='751.8545' y='14' fill='#000' fill-opacity='.3' textLength='19.047800000000002'>test</text>
- <text x='751.3545' y='13' fill='#fff' textLength='19.047800000000002'>test</text>
+ <text x='103.31239000000001' y='15' fill='#000' fill-opacity='.3' textLength='141.62478000000002'>tenant.application.default</text>
+ <text x='102.81239000000001' y='14' fill='#fff' textLength='141.62478000000002'>tenant.application.default</text>
+ <text x='222.87772' y='15' fill='#000' fill-opacity='.3' textLength='65.50588'>system-test</text>
+ <text x='222.37772' y='14' fill='#fff' textLength='65.50588'>system-test</text>
+ <text x='299.278335' y='15' fill='#000' fill-opacity='.3' textLength='55.29535'>us-west-1</text>
+ <text x='298.778335' y='14' fill='#fff' textLength='55.29535'>us-west-1</text>
+ <text x='353.15818' y='15' fill='#000' fill-opacity='.3' textLength='36.46434'>deploy</text>
+ <text x='352.65818' y='14' fill='#fff' textLength='36.46434'>deploy</text>
+ <text x='389.86664' y='15' fill='#000' fill-opacity='.3' textLength='20.95258'>test</text>
+ <text x='389.36664' y='14' fill='#fff' textLength='20.95258'>test</text>
+ <text x='459.26339' y='15' fill='#000' fill-opacity='.3' textLength='85.84091999999998'>aws-us-east-1a</text>
+ <text x='458.76339' y='14' fill='#fff' textLength='85.84091999999998'>aws-us-east-1a</text>
+ <text x='560.3496' y='15' fill='#000' fill-opacity='.3' textLength='84.33149999999999'>ap-southeast-1</text>
+ <text x='559.8496' y='14' fill='#fff' textLength='84.33149999999999'>ap-southeast-1</text>
+ <text x='628.74752' y='15' fill='#000' fill-opacity='.3' textLength='36.46434'>deploy</text>
+ <text x='628.24752' y='14' fill='#fff' textLength='36.46434'>deploy</text>
+ <text x='665.45598' y='15' fill='#000' fill-opacity='.3' textLength='20.95258'>test</text>
+ <text x='664.95598' y='14' fill='#fff' textLength='20.95258'>test</text>
+ <text x='719.990795' y='15' fill='#000' fill-opacity='.3' textLength='56.11705'>eu-west-1</text>
+ <text x='719.490795' y='14' fill='#fff' textLength='56.11705'>eu-west-1</text>
+ <text x='774.2814900000001' y='15' fill='#000' fill-opacity='.3' textLength='36.46434'>deploy</text>
+ <text x='773.7814900000001' y='14' fill='#fff' textLength='36.46434'>deploy</text>
+ <text x='810.98995' y='15' fill='#000' fill-opacity='.3' textLength='20.95258'>test</text>
+ <text x='810.48995' y='14' fill='#fff' textLength='20.95258'>test</text>
</g>
</svg>
diff --git a/controller-server/src/main/java/com/yahoo/vespa/hosted/controller/restapi/deployment/Badges.java b/controller-server/src/main/java/com/yahoo/vespa/hosted/controller/restapi/deployment/Badges.java
index 61b8ffc4b89..9950b11b74d 100644
--- a/controller-server/src/main/java/com/yahoo/vespa/hosted/controller/restapi/deployment/Badges.java
+++ b/controller-server/src/main/java/com/yahoo/vespa/hosted/controller/restapi/deployment/Badges.java
@@ -41,9 +41,9 @@ public class Badges {
return 32 <= codePoint && codePoint <= 126 ? widths[codePoint - 32] : widths[95];
}
/** Computes an approximate pixel width of a 10px size Verdana font rendering of the given string, ignoring kerning. */
public static double widthOf(String text) {
- return text.codePoints().mapToDouble(Badges::widthOf).sum() / 10;
+ return text.codePoints().mapToDouble(Badges::widthOf).sum() * 11 / 100;
}
static String colorOf(Run run, Boolean wasOk) {
@@ -71,8 +71,8 @@ public class Badges {
static final String failure = "#bf103c";
static void addText(List<String> texts, String text, double x, double width) {
- texts.add(" <text x='" + (x + 0.5) + "' y='14' fill='#000' fill-opacity='.3' textLength='" + width + "'>" + text + "</text>\n");
- texts.add(" <text x='" + x + "' y='13' fill='#fff' textLength='" + width + "'>" + text + "</text>\n");
+ texts.add(" <text x='" + (x + 0.5) + "' y='15' fill='#000' fill-opacity='.3' textLength='" + width + "'>" + text + "</text>\n");
+ texts.add(" <text x='" + x + "' y='14' fill='#fff' textLength='" + width + "'>" + text + "</text>\n");
}
static void addShade(List<String> sections, double x, double width) {
@@ -262,7 +262,7 @@ public class Badges {
" <rect x='" + (width - 2) + "' width='" + 2 + "' height='20' fill='url(#right-shadow)'/>\n" +
" <rect width='" + width + "' height='20' fill='url(#light)'/>\n" +
" </g>\n" +
- " <g fill='#fff' text-anchor='middle' font-family='Verdana,Geneva,DejaVu Sans,sans-serif' text-rendering='geometricPrecision' font-size='10'>\n" +
+ " <g fill='#fff' text-anchor='middle' font-family='Verdana,Geneva,DejaVu Sans,sans-serif' text-rendering='geometricPrecision' font-size='11'>\n" +
// The vespa.ai logo (with a slightly coloured shadow)!
" <svg x='" + (xPad + 0.5) + "' y='" + ((20 - logoSize) / 2 + 1) + "' width='" + logoSize + "' height='" + logoSize + "' viewBox='0 0 150 150'>\n" +
" <polygon fill='#402a14' fill-opacity='0.5' points='84.84 10 34.1 44.46 34.1 103.78 84.84 68.02 135.57 103.78 135.57 44.46 84.84 10'/>\n" +
@@ -41,9 +41,9 @@ public class Badges {
return 32 <= codePoint && codePoint <= 126 ? widths[codePoint - 32] : widths[95];
}
- /** Computes an approximate pixel width of a 10px size Verdana font rendering of the given string, ignoring kerning. */
+ /** Computes an approximate pixel width of a 11px size Verdana font rendering of the given string, ignoring kerning. */
public static double widthOf(String text) {